import React, { useState } from "react";
import _ from "lodash";

import tick from "./tick.png";
import danger from "./danger.png";

interface Types {
  lang?: string;
  theme?: string;
  inputMode?: any;
  label?: string;
  status?: boolean;
  maxLength?: number;
  message?: string;
}

const langDetector = (lang: string, option1: any, option2: any) => {
  return lang === "fa" ? option1 : option2;
};

const inputStatusHandler = (
  value: string,
  focus: boolean,
  status: boolean,
  primary: string,
  success: string,
  danger: string
) => {
  if (!focus) {
    return "";
  } else {
    if (!value) {
      return primary;
    } else {
      if (status) {
        return success;
      } else {
        return danger;
      }
    }
  }
};

export default function Input(props: Types) {
  const [value, setValue] = useState("");
  const [focusToggle, setFocusToggle] = useState(false);

  const { lang, theme, inputMode, label, status, maxLength, message } = props;

  const onChange = (val: string) => {
    setValue(val);
  };

  return (
    <div
      className={_.join(
        ["input", langDetector(lang as string, "fa", "en")],
        " "
      )}
    >
      <label
        className={_.join(
          [
            langDetector(lang as string, "input__labelFa", "input__labelEn"),
            "transition",
            inputStatusHandler(
              value,
              focusToggle,
              status as boolean,
              "input__labelFocus",
              "input__labelSuccess",
              "input__labelDanger"
            ),
          ],
          " "
        )}
        onClick={() => setFocusToggle(true)}
      >
        {label}
      </label>
      <input
        type="text"
        inputMode={inputMode}
        className={_.join(
          [
            inputStatusHandler(
              value,
              focusToggle,
              status as boolean,
              "input__inputActive",
              "input__inputSuccess",
              "input__inputDanger"
            ),
            "transition",
          ],
          " "
        )}
        onChange={(e: any) => onChange(e.target.value)}
        value={value}
        onFocus={() => setFocusToggle(true)}
        onBlur={() => !value && setFocusToggle(false)}
        maxLength={maxLength}
      />
      {!status && value && (
        <img
          src={danger}
          alt={langDetector(lang as string, "اشتباه", "wrong")}
          className={_.join(
            [langDetector(lang as string, "input__iconFa", "input__iconEn")],
            " "
          )}
        />
      )}
      {status && value && (
        <img
          src={tick}
          alt={langDetector(lang as string, "درست", "right")}
          className={_.join(
            [langDetector(lang as string, "input__iconFa", "input__iconEn")],
            " "
          )}
        />
      )}

      {value && !status && (
        <span
          className={_.join(
            [
              "input__message",
              langDetector(
                lang as string,
                "input__messageFa",
                "input__messageEn"
              ),
              inputStatusHandler(
                value,
                focusToggle,
                status as boolean,
                "",
                "input__messageSuccess",
                "input__messageDanger"
              ),
              "transition",
            ],
            " "
          )}
        >
          {message}
        </span>
      )}
      {value && (
        <span
          className={_.join(
            [
              "input__length",
              langDetector(
                lang as string,
                "input__lengthFa",
                "input__lengthEn"
              ),
              inputStatusHandler(
                value,
                focusToggle,
                status as boolean,
                "",
                "input__lengthSuccess",
                "input__lengthDanger"
              ),
              "transition",
            ],
            " "
          )}
        >
          {value.length + '/' + maxLength}
        </span>
      )}
    </div>
  );
}
