import React, { useState } from "react";
import _ from "lodash";
import searchIcon from "./icon.png";
import xIcon from "./x.png";

interface Types {
  lang?: string;
  theme?: string;
  populars?: Array<string>;
}

const langDetector = (lang: string, option1: any, option2: any) => {
  return lang === "fa" ? option1 : option2;
};

export default function PopularSearch(props: Types) {
  const [value, setValue] = useState("");
  const [popularsToggle, setPopularsToggle] = useState(false);
  const { lang, theme, populars } = props;

  const onChange = (val: string) => {
    setValue(val);
  };

  return (
    <div
      className={_.join(
        ["search", langDetector(lang as string, "fa", "en")],
        " "
      )}
    >
      <input
        type="search"
        className="transition"
        onChange={(e: any) => onChange(e.target.value)}
        value={value}
        placeholder={langDetector(
          lang as string,
          "نام کالا را جستجو کنید",
          "search product name"
        )}
        onFocus={() => setPopularsToggle(true)}
        onBlur={() => setPopularsToggle(false)}
      />
      <img
        src={searchIcon}
        alt={langDetector(lang as string, "جستجو", "search")}
        className={_.join(
          [
            "search__icon",
            langDetector(lang as string, "search__iconFa", "search__iconEn"),
          ],
          " "
        )}
      />
      <img
        src={xIcon}
        alt={langDetector(lang as string, "پاک کردن", "clear")}
        className={_.join(
          [
            "search__x",
            "transition",
            langDetector(lang as string, "search__xFa", "search__xEn"),
            value ? "search__xActive" : "",
          ],
          " "
        )}
        onClick={() => setValue("")}
      />
      <div
        className={_.join(
          [
            "search__populars",
            popularsToggle ? "search__popularsActive" : "",
            "transition",
          ],
          " "
        )}
      >
        <strong>
          {langDetector(lang as string, "جستجوهای پرطرفدار", "Popular search")}
        </strong>
        <ul>
          {populars?.map((item: string, i: any) => (
            <>
              <li key={i} className="transition" onClick={() => setValue(() => item)}>
                {item}
              </li>
              {i !== populars?.length - 1 && <hr />}
            </>
          ))}
        </ul>
      </div>
    </div>
  );
}

PopularSearch.defaultProps = {
  lang: "fa",
  theme: "light",
  populars: ["علی", "علیرضا", "محمد", "محمدرضا"],
};
