import React, { useState } from "react";
import _ from "lodash";
import searchIcon from "./icon.png";
import xIcon from "./x.png";

interface Types {
  lang?: string;
  theme?: string;
}

const langDetector = (lang: string, option1: any, option2: any) => {
  return lang === "fa" ? option1 : option2;
};

export default function Search(props: Types) {
  const [value, setValue] = useState("");
  const { lang, theme } = props;

  const onChange = (val: string) => {
    setValue(val);
  };

  return (
    <div
      className={_.join(
        ["search", langDetector(lang as string, "fa", "en")],
        " "
      )}
    >
      <input
        type="search"
        className="transition"
        onChange={(e: any) => onChange(e.target.value)}
        value={value}
        placeholder={langDetector(
          lang as string,
          "نام کالا را جستجو کنید",
          "search product name"
        )}
      />
      <img
        src={searchIcon}
        alt={langDetector(lang as string, "جستجو", "search")}
        className={_.join([
          "search__icon",
          langDetector(lang as string, "search__iconFa", "search__iconEn"),
        ], " ")}
      />
      <img
        src={xIcon}
        alt={langDetector(lang as string, "پاک کردن", "clear")}
        className={_.join([
          "search__x",
          "transition",
          langDetector(lang as string, "search__xFa", "search__xEn"),
          value ? "search__xActive" : "",
        ], " ")}
        onClick={() => setValue("")}
      />
    </div>
  );
}

Search.defaultProps = {
  lang: "fa",
  theme: "light",
};
