import React, { useState } from "react";
import _ from "lodash";
import Radio from "../Radio";

import xIcon from "./x.png";
import arrowIcon from "./arrow.png";

interface Types {
  lang?: string;
  theme?: string;
  list?: Array<object>;
  label?: string;
}

interface Value {
  icon: any;
  name: string;
}

// const inputStatusHandler = (
//   value: string,
//   focus: boolean,
//   status: boolean,
//   primary: string,
//   success: string,
//   danger: string
// ) => {
//   if (!focus) {
//     return "";
//   } else {
//     if (!value) {
//       return primary;
//     } else {
//       if (status) {
//         return success;
//       } else {
//         return danger;
//       }
//     }
//   }
// };

const langDetector = (lang: string, option1: any, option2: any) => {
  return lang === "fa" ? option1 : option2;
};

export default function SelectRadio(props: Types) {
  const [selectedItem, setSelectedItem] = useState("");
  const [value, setValue] = useState<string>("");

  const [toggle, setToggle] = useState(false);
  const { lang, theme, list, label } = props;

  const onChangeItem = (val: string) => {
    setSelectedItem(val);
  };

  const onChangeText = (val: string) => {
    setValue(val);
  };

  return (
    <div
      className={_.join(
        ["select-search", langDetector(lang as string, "fa", "en")],
        " "
      )}
    >
      <div
        className={_.join(
          ["search", langDetector(lang as string, "fa", "en")],
          " "
        )}
        onClick={() => setToggle(() => !toggle)}
      >
        <input
          type="search"
          className="transition"
          onChange={(e: any) => onChangeText(e.target.value)}
          placeholder={langDetector(lang as string, "تنظیمات", "setting")}
          disabled
        />
        <img
          src={arrowIcon}
          alt={langDetector(lang as string, "جستجو", "search")}
          className={_.join(
            [
              "search__icon",
              langDetector(lang as string, "search__iconFa", "search__iconEn"),
            ],
            " "
          )}
        />
        <img
          src={xIcon}
          alt={langDetector(lang as string, "پاک کردن", "clear")}
          className={_.join(
            [
              "search__x",
              "transition",
              langDetector(lang as string, "search__xFa", "search__xEn"),
              value ? "search__xActive" : "",
            ],
            " "
          )}
          onClick={() => setValue("")}
        />
      </div>
      {toggle && (
        <div
          className={_.join(
            [
              "select-search__list",
              toggle ? "select-search__listActive" : "",
              "transition",
            ],
            " "
          )}
        >
          <ul>
            {list?.map((item: any, i: any) => (
              <>
                <li key={i} className="transition">
                    <Radio checked={false} label={item?.name} />
                </li>
                {i !== list?.length - 1 && <hr />}
              </>
            ))}
          </ul>
        </div>
      )}
    </div>
  );
}

SelectRadio.defaultProps = {
  lang: "fa",
  theme: "light",
  label: "کشور خود را انتخاب کنید",
  list: [
    { name: "وسایل آشپزخانه", sublist: [{ name: "اتو" }] },
    { name: "غریق نجات از تمام جهات" },
    { name: "قاشق و چنگال" },
    { name: "وسایل آشپزخانه" },
  ],
};
