import React, { useState } from "react";
import _ from "lodash";

import iran from "./iran.png";
import iraq from "./iraq.png";
import spain from "./spain.png";
import uk from "./united-kingdom.png";
import arrow from "./arrow.png";

import searchIcon from "./icon.png";
import xIcon from "./x.png";

interface Types {
  lang?: string;
  theme?: string;
  countries?: Array<object>;
  label?: string;
}

interface Value {
  icon: any;
  name: string;
}

// const inputStatusHandler = (
//   value: string,
//   focus: boolean,
//   status: boolean,
//   primary: string,
//   success: string,
//   danger: string
// ) => {
//   if (!focus) {
//     return "";
//   } else {
//     if (!value) {
//       return primary;
//     } else {
//       if (status) {
//         return success;
//       } else {
//         return danger;
//       }
//     }
//   }
// };

const langDetector = (lang: string, option1: any, option2: any) => {
  return lang === "fa" ? option1 : option2;
};

export default function SelectSearch(props: Types) {
  const [selectedItem, setSelectedItem] = useState("");
  const [value, setValue] = useState<string>("");

  const [toggle, setToggle] = useState(false);
  const { lang, theme, countries, label } = props;

  const onChangeItem = (val: string) => {
    setSelectedItem(val);
  };

  const onChangeText = (val: string) => {
    setValue(val);
  };

  return (
    <div
      className={_.join(
        ["select-search", langDetector(lang as string, "fa", "en")],
        " "
      )}
    >
      <div
        className={_.join(
          ["search", langDetector(lang as string, "fa", "en")],
          " "
        )}
      >
        <input
          type="search"
          className="transition"
          onChange={(e: any) => onChangeText(e.target.value)}
          onFocus={(e: any) => setToggle(true)}
          onBlur={(e: any) => setTimeout(() => {setToggle(false)}, 300)}
          value={selectedItem}
          placeholder={langDetector(
            lang as string,
            "نام کالا را جستجو کنید",
            "search product name"
          )}
        />
        <img
          src={searchIcon}
          alt={langDetector(lang as string, "جستجو", "search")}
          className={_.join(
            [
              "search__icon",
              langDetector(lang as string, "search__iconFa", "search__iconEn"),
            ],
            " "
          )}
        />
        <img
          src={xIcon}
          alt={langDetector(lang as string, "پاک کردن", "clear")}
          className={_.join(
            [
              "search__x",
              "transition",
              langDetector(lang as string, "search__xFa", "search__xEn"),
              value ? "search__xActive" : "",
            ],
            " "
          )}
          onClick={() => setValue("")}
        />
      </div>
      {toggle && (
        <div
          className={_.join(
            [
              "select-search__list",
              toggle ? "select-search__listActive" : "",
              "transition",
            ],
            " "
          )}
        >
          <ul onClick={() => setToggle(false)}>
            {countries?.map((item: any, i: any) => (
              <>
                <li
                  key={i}
                  className="transition"
                  onClick={(e) => setSelectedItem(item.name)}
                >
                  <img src={item?.icon} alt="" />

                  {item?.name}
                </li>
                {i !== countries?.length - 1 && <hr />}
              </>
            ))}
          </ul>
        </div>
      )}
    </div>
  );
}

SelectSearch.defaultProps = {
  lang: "fa",
  theme: "light",
  label: "کشور خود را انتخاب کنید",
  countries: [
    { name: "IRAN", icon: iran },
    { name: "IRAQ", icon: iraq },
    { name: "SPAIN", icon: spain },
    { name: "UK", icon: uk },
  ],
};
